@@ -69,7 +69,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -103,7 +103,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -137,7 +137,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -172,7 +172,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -211,7 +211,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -253,7 +253,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             None,
             False,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -363,7 +363,7 @@ class TestIdentityProviderShow(TestIdentityProvider):
             identity_fakes.idp_description,
             True,
             identity_fakes.idp_id,
-            identity_fakes.idp_remote_ids
+            identity_fakes.formatted_idp_remote_ids
         )
         self.assertEqual(datalist, data)
 
@@ -374,6 +374,50 @@ class TestIdentityProviderSet(TestIdentityProvider):
         super(TestIdentityProviderSet, self).setUp()
         self.cmd = identity_provider.SetIdentityProvider(self.app, None)
 
+    def test_identity_provider_set_description(self):
+        """Set Identity Provider's description. """
+        def prepare(self):
+            """Prepare fake return objects before the test is executed"""
+            updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
+            updated_idp['enabled'] = False
+            resources = fakes.FakeResource(
+                None,
+                updated_idp,
+                loaded=True
+            )
+            self.identity_providers_mock.update.return_value = resources
+
+        prepare(self)
+        new_description = 'new desc'
+        arglist = [
+            '--description', new_description,
+            identity_fakes.idp_id
+        ]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('description', new_description),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        self.identity_providers_mock.update.assert_called_with(
+            identity_fakes.idp_id,
+            description=new_description
+        )
+
+        collist = ('description', 'enabled', 'id', 'remote_ids')
+        self.assertEqual(collist, columns)
+        datalist = (
+            identity_fakes.idp_description,
+            False,
+            identity_fakes.idp_id,
+            identity_fakes.idp_remote_ids
+        )
+        self.assertEqual(datalist, data)
+
     def test_identity_provider_disable(self):
         """Disable Identity Provider
 
@@ -398,6 +442,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
+            ('description', None),
             ('enable', False),
             ('disable', True),
             ('remote_id', identity_fakes.idp_remote_ids)
@@ -443,6 +488,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
+            ('description', None),
             ('enable', True),
             ('disable', False),
             ('remote_id', identity_fakes.idp_remote_ids)
@@ -488,6 +534,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
+            ('description', None),
             ('enable', True),
             ('disable', False),
             ('remote_id', [self.new_remote_id])
@@ -533,6 +580,7 @@ class TestIdentityProviderSet(TestIdentityProvider):
         ]
         verifylist = [
             ('identity_provider', identity_fakes.idp_id),
+            ('description', None),
             ('enable', True),
             ('disable', False),
             ('remote_id_file', self.new_remote_id),
